@@ -3,11 +3,12 @@ PyFeyn - a simple Python interface for making Feynman diagrams.
 """
 
 __author__ = "Andy Buckley & Georg von Hippel (pyfeyn@projects.hepforge.org)"
-__version__ = "0.3.2"
-__date__ = "$Date: 2009-01-08 12:57:43 +0100 (Thu, 08 Jan 2009) $"
-__copyright__ = "Copyright (c) 2007 Andy Buckley"
+__version__ = "0.3.3"
+__date__ = "2013-10-03"
 __license__ = "GPL"
 
+## Set __all__ (for "from pyfeyn import *")
+__all__ = ["diagrams", "points", "blobs", "lines", "deco", "utils", "config"]
 
 ## Import PyX and set up some things
 try:
@@ -24,12 +25,10 @@ try:
 
     ## TeX stuff
     pyx.text.defaulttexrunner.set(mode="latex")
-    if pyx.pykpathsea.find_file("hepnicenames.sty", pyx.pykpathsea.kpse_tex_format):
-        pyx.text.defaulttexrunner.preamble(r"\usepackage{hepnicenames}")
+    if pyx.pykpathsea.find_file("hepnames.sty", pyx.pykpathsea.kpse_tex_format):
+        pyx.text.defaulttexrunner.preamble(r"\usepackage{hepnames}")
     else:
         print "Warning: hepnames LaTeX package not found!"
 
-    ## Set __all__ (for "from pyfeyn import *")
-    __all__ = ["diagrams", "points", "blobs", "lines", "deco", "utils", "config"]
 except:
     print "You don't have PyX - that's a problem unless you're just running the setup script."
